==> gmic_3.0.0.tar.gz: gmic-3.0.0/gmic-qt/src/FilterParameters/BoolParameter.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file BoolParameter.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_BOOLPARAMETER_H
#define GMIC_QT_BOOLPARAMETER_H

#include <QString>
#include "AbstractParameter.h"
class QCheckBox;
class QLabel;

namespace GmicQt
{

class BoolParameter : public AbstractParameter {
  Q_OBJECT
public:
  BoolParameter(QObject * parent);
  ~BoolParameter() override;
  virtual int size() const override;
  bool addTo(QWidget *, int row) override;
  QString value() const override;
  QString defaultValue() const override;
  void setValue(const QString & value) override;
  void reset() override;
  bool initFromText(const char * text, int & textLength) override;
public slots:
  void onCheckBoxChanged(bool);

private:
  void connectCheckBox();
  void disconnectCheckBox();
  QString _name;
  bool _default;
  bool _value;
  QLabel * _label;
  QCheckBox * _checkBox;
  bool _connected;
};

} // namespace GmicQt

#endif // GMIC_QT_BOOLPARAMETER_H

==> gmic_3.0.1.tar.gz: gmic-3.0.1/gmic-qt/src/FilterParameters/BoolParameter.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file BoolParameter.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_BOOLPARAMETER_H
#define GMIC_QT_BOOLPARAMETER_H

#include <QString>
#include "AbstractParameter.h"
class QCheckBox;
class QLabel;

namespace GmicQt
{

class BoolParameter : public AbstractParameter {
  Q_OBJECT
public:
  BoolParameter(QObject * parent);
  ~BoolParameter() override;
  virtual int size() const override;
  bool addTo(QWidget *, int row) override;
  QString value() const override;
  QString defaultValue() const override;
  void setValue(const QString & value) override;
  void reset() override;
  bool initFromText(const QString & filterName, const char * text, int & textLength) override;
public slots:
  void onCheckBoxChanged(bool);

private:
  void connectCheckBox();
  void disconnectCheckBox();
  QString _name;
  bool _default;
  bool _value;
  QLabel * _label;
  QCheckBox * _checkBox;
  bool _connected;
};

} // namespace GmicQt

#endif // GMIC_QT_BOOLPARAMETER_H
